=======
Credits
=======

Development Lead
----------------

* Daniel Greenfeld <pydanny@gmail.com>

Contributors
------------

* Tin Tvrtković <tinchester@gmail.com>
* @bcho <bcho@vtmer.com>
* George Sakkis (@gsakkis)
